/**
 * InsertForm.java
 *
 * This class represents the form for adding a new record to the database. This uses a
 * GridBagLayout and places the various textfield and list components in the panel 
 * appropriately. It uses the Connection class to connect to the server and send the
 * data to the server. This class is called when the New button in the left panel is
 * clicked. It implements the ActionListener interface so that the Submit and Cancel 
 * button clicks can be trapped.
 * 
 * @author xjqiu@npac.syr.edu
 */

import java.awt.*;
import java.awt.event.*;

public class InsertForm extends Panel  // class definition
        implements ActionListener {

 GridBagLayout gb = new GridBagLayout();  // use a GridBagLayout
 GridBagConstraints gbc = new GridBagConstraints();  // constraints for the layout

 private Color fg = new Color(0,80,80); //foreground color
 private Color buttonbg = new Color(166,166,166); //background color
 private Color buttonfg = new Color(3,61,52); //foreground color
 private DayList day; //components for DayList
 private TimeList time; //components for TimeList
 private TextField course, refno, cname, instr, location; // text boxes for fields
 private Button submit,cancel; // buttons for submit and cancel
 private Label l1,l2, l3, l4, l5, l6,l7 ; // labels for the textboxes and buttons
 private StatusWin swin; // Status Window for client server interactions

// private Connection con; // Connection class

/**
 * Constructor for the class. Sets up the various components in the panel
 * appropriately according to the constraints.
 */

 public InsertForm() {

     setLayout(gb);  //sets the layout
     setBackground(Color.white); //sets background color

     gbc.fill = GridBagConstraints.NONE;
     gbc.anchor = GridBagConstraints.NORTHWEST; // sets anchor as NORTHWEST

     l1 = makeLabel(" Dept/Course/Section : "); //adds text boxes
     addComp(l1,4,0,1,1,new Insets(-235,0,1,1));
     course = new TextField(15);
     addComp(course,9,5,1,1,new Insets(-235,2,1,1));

     l2 = makeLabel(" Reference No. : ");
     addComp(l2,4,7,1,1,new Insets(-205,0,1,1));
     refno = new TextField(10);
     addComp(refno,9,7,1,2,new Insets(-205,2,1,1));

     l3 = makeLabel(" Course Name : ");
     addComp(l3,4,9,1,1,new Insets(-175,0,1,1));
     cname = new TextField(30);
     addComp(cname,9,9,1,1,new Insets(-175,2,1,1));

     l4 = makeLabel(" Instructor : ");
     addComp(l4,4,11,1,1,new Insets(-145,0,1,1));
     instr = new TextField(20);
     addComp(instr,9,11,1,1,new Insets(-145,2,1,1));
  
     l5 = makeLabel(" Location : ");
     addComp(l5,4,13,1,1,new Insets(-130,0,1,1));
     location = new TextField(15);
     addComp(location,9,13,1,1,new Insets(-130,2,1,1));

     l6 = makeLabel(" Day  :"); //add from label and city list
     addComp(l6,4,15,1,1,new Insets(-90,0,1,1));
     day = new DayList("MW");
     day.setBackground(fg);
     day.setForeground(Color.white);
     addComp(day,4,17,1,1,new Insets(-65,0,1,1));

     l7 = makeLabel(" Time :"); //add to label and city list
     addComp(l7,9,15,1,1,new Insets(-90,2,1,1));
     time = new TimeList("8:30-10:45am");
     time.setBackground(fg);
     time.setForeground(Color.white);
     addComp(time,9,17,1,1,new Insets(-65,2,1,1));


     submit = new Button("Submit"); //add submit and cancel and their action listeners
     submit.setBackground(buttonbg);     // which is this class itself
     submit.setForeground(buttonfg);
     submit.setFont(new Font("Helvetica", Font.BOLD, 14));
     submit.addActionListener(this);
     addComp(submit,4,11,1,2,new Insets(-5,0,1,1));
     cancel = new Button("Cancel");
     cancel.setBackground(buttonbg);
     cancel.setForeground(buttonfg);
     cancel.setFont(new Font("Helvetica", Font.BOLD, 14));
     cancel.addActionListener(this);
     addComp(cancel,9,11,1,3,new Insets(-5,1,1,1));


     swin = new StatusWin("InsertForm"); // adds a status window compoenent to the panel
     addComp(swin,0,402,0,0,new Insets(50,20,-465,3));

     //show instruction for Insert in the status window
     dispInsertInstruction(); //show instruction for Insert in the status window 
}


/**
 * paint method called by the browser for drawing a separator line
 */

 public void paint(Graphics g) {
     g.drawLine(0,300,500,300);
 }

 /**
 * Method that actually sets the parameters and adds the component
 * to the panel. Gets the coordinates, width and height and insets
 * as well as the component object as arguments.
 */

 private void addComp
            ( Component c, int x, int y, int ht, int wt, Insets insets ) {
     gbc.gridx = x;
     gbc.gridy = y;

     gbc.gridwidth = wt;
     gbc.gridheight = ht;

     gbc.insets = insets;

     gb.setConstraints(c,gbc);
     add(c);
 }


/**
 * Helper method in constructing labels. Sets the foreground and background colors
 * fonts etc.
 */

 private Label makeLabel(String str) {
     Label l = new Label(str);
     l.setForeground(fg);
     l.setFont(new Font("Helvetica", Font.BOLD, 11));
     return l;
 }

/**
 * The Action Listener implementation which is called when the submit and cancel
 * buttons are clicked.  It uses the doPost method to contact the server if the submit
 * button had been clicked.
 */

 public void actionPerformed(ActionEvent e) {
     Button b = (Button) e.getSource(); //get the button 
   
     String tmpstr = b.getLabel().trim(); // get the label of the button

     if(tmpstr.equals("Submit")) {
          try {
                String  sql = getSQLstringForInsert(); 
          		boolean insertflag = CourseApplet.obj.insert(sql); //remote method for INSERT
  
          		if (insertflag == true) { 
                	swin.writeMsg("\n             * RECORD HAS BEEN ADDED * \n");
                	System.out.println("InsertForm->actionPerformed: New record has been added to database file.");
                }
           }catch (Exception ex) {
                System.out.println("InsertForm->actionPerformed: Exception in INSERT : " + ex);
                ex.printStackTrace();
           }
     }else if(tmpstr.equals("Cancel")) { //check if it is cancel
         clearAll();
     }

     b = null; 
     tmpstr = null;
 }


/**
 * This method forms SQL string for INSERT
 */

private String getSQLstringForInsert() {
     String  sql;
     String  bgstr = "insert into course_table (id, course,refno,cname,instr,location,day,time) values( ";
     String  endstr= " )";
     
     sql = bgstr+ getValues() + endstr;

     System.out.println("insertForm->getSQLstringForInsert: sql is : " + sql);
     return sql;  //return the SQL string for INSERT
}



/**
 * This method gets the values from the various text boxes 
 * and list components.
 */

 private String getValues() {
     StringBuffer sb = new StringBuffer(); // construct a big string from the textfield and list field values 
   
     String courseVar = course.getText();
     String refnoVar  = refno.getText();
     String cnameVar  = cname.getText();
     String instrVar  = instr.getText();
     String locationVar = location.getText();
     String dayVar    = day.getSelectedItem();
     String timeVar   = time.getSelectedItem(); 

 
     sb.append("course_table_seq.nextval");
     sb.append(",'"+courseVar+"',");
     sb.append("'"+refnoVar+"',");
     sb.append("'"+cnameVar+"',");
     sb.append("'"+instrVar+"',");
     sb.append("'"+locationVar+"',");
     sb.append("'"+dayVar+"',");
     sb.append("'"+timeVar+"'");  
  
     return sb.toString(); // return the string
 }


/**
 * Instruciton for Insert in the status window
 */

  public void dispInsertInstruction() { 
     swin.writeMsg("\n                * SAMPLE INSERT *\n");
     swin.writeMsg("Fill in the text fields and choose items from lists:");
     swin.writeMsg("Dept/Course/Section --> 'CIS/554/2'");
     swin.writeMsg("Reference No. --> '59071'");
     swin.writeMsg("Course Name --> 'Object Oriented Programming in C++ Laboratory'");
     swin.writeMsg("Instructor --> 'Pease'");
     swin.writeMsg("Location --> '221 AG'");
     swin.writeMsg("Day --> 'T'");
     swin.writeMsg("Time --> '4:15-6:30pm'");
     swin.writeMsg("ress 'Submit' button to perform INSERT");
     swin.writeMsg("Press 'Cancel' button to CLEAR textfields and status window");
     swin.writeMsg("\n 'SEARCH' can be used to look up input record\n");
  }

/**
 * This method clears all the text boxes and sets default values to the 
 * list boxes.
 */

 public void clearAll() {
     setDefault();
     clearStatusWin();
 }


/**
 * This method clears all the text boxes and sets default values for the choice lists
 */

 private void setDefault(){
       day.select("MW");
       time.select("8:30-10:45am");    
       course.setText("");
       refno.setText("");
       cname.setText("");
       instr.setText("");
       location.setText("");
 }


/**
 * This method clears the status window
 */

 private void clearStatusWin() {
     swin.setText(" ");
 }

} // end of class
